<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/src/notification/bubble.cpp" line="325"/>
        <source>1 new message</source>
        <translation>1 yeni ileti</translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="232"/>
        <source>Just Now</source>
        <translation>Hemen Şimdi</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="234"/>
        <source>%1 minutes ago</source>
        <translation>%1 dakika önce</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="236"/>
        <source>%1 hours ago</source>
        <translation>%1 saat önce</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="239"/>
        <source>Yesterday </source>
        <translation>Dün</translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="272"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="273"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="88"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>Yayım</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>Bu uygulama sonlandırılacak, lütfen verilerinizin kaydedildiğinden emin olun!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="56"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>Lütfen belgenizi, metninizi ve hesap tablonuzu kaydedin</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="89"/>
        <source>Continue</source>
        <translation>Devam</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="110"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>Sistem belleği yetersiz, zorlanmamak için lütfen bazı uygulamaları kapatınız.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="222"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>%1 çalıştırmaya devam edebilmek için %2MB bellek gereklidir</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="225"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>Tarayıcı sekmesi açmaya devam edebilmek için %1MB bellek gereklidir</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="228"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>Çalışmaya devam edebilmek için %1MB bellek gereklidir</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="234"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>Mevcut bellek yeterli, çalıştırılmaya devam edilsin mi %1?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="237"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>Mevcut bellek yeterli, tarayıcı sekmesini açmaya devam edilsin mi?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="240"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>Mevcut bellek yeterli, çalışmaya devam edilsin mi?</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="292"/>
        <source>Only on %1</source>
        <translation>Yanlız %1 üzerinde</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="294"/>
        <source>Duplicate</source>
        <translation>Çoğalt</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="296"/>
        <source>Extend</source>
        <translation>Genişlet</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/src/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>Klavye düzeni ekle</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="107"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>Bağlanmak için parola gerekli  &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="179"/>
        <source>Wrong password, please enter again!</source>
        <translation>Yanlış parola, lütfen tekrar girin!</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifycenterwidget.cpp" line="97"/>
        <source>Notification Center</source>
        <translation>Bildirim Merkezi</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>Sistem bildirimi yok</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="138"/>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
        <source>WLAN on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
        <source>WLAN off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
        <source>Caps Lock on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
        <source>Caps Lock off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
        <source>Numeric keypad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="132"/>
        <source>Numeric keypad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="134"/>
        <source>Touchpad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="135"/>
        <source>Touchpad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="136"/>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="140"/>
        <source>Airplane mode on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="141"/>
        <source>Airplane mode off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="143"/>
        <source>Mute on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="144"/>
        <source>Mute off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
        <source>Balanced power</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
        <source>Power saver</source>
        <translation>Güç tasarrufu</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="148"/>
        <source>High performance</source>
        <translation>Yüksek performans</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="150"/>
        <source>Window effect enabled</source>
        <translation>Pencere etkisi etkinleştirildi</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="151"/>
        <source>Window effect disabled</source>
        <translation>Pencere etkisi devre dışı bırakıldı</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="152"/>
        <source>Failed to enable window effects</source>
        <translation>Pencere etkileri etkinleştirilemedi</translation>
    </message>
</context>
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
        <source>Passwords do not match</source>
        <translation>Parolalar eşleşmiyor</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>İpucu tüm kullanıcılar tarafından görülebilir. Parolayı buraya dahil etmeyin.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="86"/>
        <source>New Password</source>
        <translation>Yeni Parola</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="120"/>
        <source>Repeat Password</source>
        <translation>Parolayı Tekrarla</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Password Hint</source>
        <translation>Parola İpucu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="137"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="138"/>
        <source>Required</source>
        <translation>Gereklidir</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="139"/>
        <source>Optional</source>
        <translation>Seçimlik</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="221"/>
        <source>Strong</source>
        <translation>Güçlü</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="231"/>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="240"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="253"/>
        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
        <translation>Güçlü bir parola tavsiye ederiz: 8 karakterden daha fazladır ve dört karakter türünden 3&apos;ünü içerir: küçük harfler, büyük harfler, sayılar ve simgeler.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="244"/>
        <source>Weak</source>
        <translation>Zayıf</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="255"/>
        <source>Error occurred when reading the configuration files of password rules!</source>
        <translation>Parola kurallarının yapılandırma dosyaları okunduğu zaman hata oluştu!</translation>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="40"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>Bluetooth aygıtına bağlanmak için PIN kodu:</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>Bitir</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="76"/>
        <source>Password cannot be empty</source>
        <translation>Parola boş olamaz</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="77"/>
        <source>Password must have at least %1 characters</source>
        <translation>Parola en az %1 karakter olmalıdır</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="78"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Parola %1 karakterden fazla olmamalıdır</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="79"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Parola yalnızca İngilizce harfler (büyük/küçük harfe duyarlı), sayılar veya özel simgeler içerebilir (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="80"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>En fazla %1 palindrom karakter lütfen</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="81"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>%1&apos;den fazla monoton karakter yok lütfen</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Lütfen %1&apos;den fazla yinelenen karakter yok</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="87"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Parola büyük harfler, küçük harfler, sayılar ve semboller içermeli (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="88"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Parola 4&apos;ten fazla tersten okunduğunda aynı olan karakter içermemelidir</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="89"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="92"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Parola olarak bilinen kelime ve kombinasyonlarını kullanmayın</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="90"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="91"/>
        <source>Create a strong password please</source>
        <translation>Lütfen güçlü bir parola oluşturun</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="97"/>
        <source>It does not meet password rules</source>
        <translation>Parola kurallarına uymuyor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="43"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="49"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="59"/>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="44"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="45"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="46"/>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="47"/>
        <source>key</source>
        <translation>anahtar</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="55"/>
        <source>Private Pwd</source>
        <translation>Özel Parola</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="58"/>
        <source>Proxy Password</source>
        <translation>Vekil Sunucu Parolası</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="60"/>
        <source>Group Password</source>
        <translation>Grup Parolası</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation>Boş olamaz</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="110"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Parolanın sıfırlanması, anahtarlıkta depolanan verileri siler</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="112"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <source>Security Questions</source>
        <translation>Güvenlik Soruları</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="156"/>
        <source>Reset Password</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="157"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Reset Password By Union ID</source>
        <translation>Parolayı Union ID ile sıfırla</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="161"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="206"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="213"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="167"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Parolayı sıfırlamak, anahtarlığınızda saklanan verileri siler ve tekrar giriş yapmalısınız, lütfen dosyaları önceden kaydedin</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <source>Confirm and Reset</source>
        <translation>Onayla ve Sıfırla</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="264"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Başarıyla sıfırladın, lütfen  yeni parola ile giriş yapın ve kilidi açın</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Gereklidir</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Doğduğun şehrin adı nedir?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>İlk okuduğun okulun adı nedir?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>Who do you love the most in this world?</source>
        <translation>Dünyada en çok kimi seviyorsun?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Gözde hayvanın nedir?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Gözde şarkın nedir?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="136"/>
        <source>What&apos;s your nickname?</source>
        <translation>Takma adın nedir?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="186"/>
        <source>Wrong answer</source>
        <translation>Yanlış cevap</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="201"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Cevap 30 karakterden az olmalıdır</translation>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>Harici ekran algılandı, askıya alınsın mı?</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="65"/>
        <source>%1s</source>
        <translation>%1s</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="45"/>
        <source>Select your touch screen</source>
        <translation>Dokunmatik ekranınızı seçin</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="55"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="63"/>
        <source>Phone/Email</source>
        <translation>Telefon/E-posta</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="69"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="136"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="289"/>
        <source>Get Code</source>
        <translation>Kodu Al</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="89"/>
        <source>Connecting to the Internet...</source>
        <translation>İnternet&apos;e bağlanıyor...</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="101"/>
        <source>The user account is not linked to Union ID</source>
        <translation>Kullanıcı hesabı Union ID&apos;ye bağlı değil</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="114"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Ağ bağlantısı kesildi, lütfen bağlandıktan sonra tekrar dene</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="134"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="135"/>
        <source>Required</source>
        <translation>Gereklidir</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="170"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="185"/>
        <source>Phone/Email format is incorrect</source>
        <translation>Telefon/E-posta biçimi yanlış</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="239"/>
        <source>System error</source>
        <translation>Sistem hatası</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="241"/>
        <source>Login expired, please sign in to the Union ID again</source>
        <translation>Girişin süresi doldu, lütfen Union ID&apos;de tekrar oturum açın</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="243"/>
        <source>Network error</source>
        <translation>Ağ hatası</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="245"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Bugün kodu almak için sayı sınırına ulaştınız</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>The Union ID is not linked to a user account</source>
        <translation>Union ID bir kullanıcı hesabına bağlı değil</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="255"/>
        <source>It cannot be empty</source>
        <translation>Boş olamaz</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="292"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="334"/>
        <source>Resend (%1s)</source>
        <translation>Yeniden gönderiliyor  (%1s)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="353"/>
        <source>Failed to get the code</source>
        <translation>Kod alımı başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="376"/>
        <source>Wrong verification code</source>
        <translation>Yanlış doğrulama kodu</translation>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="45"/>
        <source>Welcome, system updated successfully</source>
        <translation>Hoş geldiniz, sistem başarıyla güncellendi</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="46"/>
        <source>Current Edition:</source>
        <translation>Mevcut Yayın:</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="47"/>
        <source>Enter</source>
        <translation>Giriş</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>Normal Kip</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>Başarımı ve kullanım deneyimini olumsuz etkileyecek şekilde bir sanal makine kullandığınız algılandı, sorunsuz bir deneyim için Normal Kipi seçmeniz önerilir</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>Verimli Kip: Görsel olarak zevkli bir deneyim. Normal Kip: Hızlı ve yüksek başarım deneyimi</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>Arkadaşça Hatırlat</translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="38"/>
        <source>Kindly Reminder</source>
        <translation>Nazikçe Hatırlat</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="39"/>
        <source>This application cannot run without window effect</source>
        <translation>Bu uygulama pencere etkisi olmadan çalıştırılamaz</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="43"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/src/window.cpp" line="41"/>
        <source>Low battery, please plug in</source>
        <translation>Düşük pil, lütfen prize takın</translation>
    </message>
</context>
</TS>